# This file was first automatically generated by gen-acme-cpanmodules-module-from-acme-cpanlists-list on Sat Sep 22 07:52:26 2018 from module list in Acme::CPANLists::Import::PerlAdvent::2012 version 0.001.

package Acme::CPANModules::Import::PerlAdvent::2012;

our $DATE = '2018-09-22'; # DATE
our $VERSION = '0.001'; # VERSION

our $LIST = {
  description => "This list is generated by extracting module names mentioned in [http://perladvent.org/2012/] (retrieved on 2016-11-06). Visit the URL for the full contents.",
  entries     => [
                   { module => "File::Path" },
                   { module => "File::Spec" },
                   { module => "Moose" },
                   { module => "MooseX::Types::Path::Class" },
                   { module => "Path::Class" },
                   { module => "Scope::Upper" },
                   { module => "Dist::Zilla" },
                   { module => "Dist::Zilla::Plugin::ReportVersions::Tiny" },
                   { module => "Dist::Zilla::Plugin::Test::ReportPrereqs" },
                   { module => "Dancer" },
                   { module => "DBI" },
                   { module => "DDP" },
                   { module => "Data::Printer" },
                   { module => "DateTime" },
                   { module => "Digest" },
                   { module => "Digest::MD5" },
                   { module => "Safe" },
                   { module => "File::AtomicWrite" },
                   { module => "Dist::Zilla::Plugin::ShareDir::Tarball" },
                   { module => "ExtUtils::MakeMaker" },
                   { module => "File::ShareDir" },
                   { module => "File::ShareDir::Tarball" },
                   { module => "Module::Build" },
                   { module => "Module::Build::CleanInstall" },
                   { module => "Module::Build::Cookbook" },
                   { module => "Module::Pluggable" },
                   { module => "IO::Prompt::Hooked" },
                   { module => "IO::Prompt::Tiny" },
                   { module => "IO::Prompter" },
                   { module => "LWP" },
                   { module => "LWP::UserAgent" },
                   { module => "PSGI" },
                   { module => "Test::LWP::UserAgent" },
                   { module => "Test::Mock::LWP::Dispatch" },
                   { module => "Term::ExtendedColor" },
                   { module => "Web::Machine" },
                   { module => "pp" },
                   { module => "App::FatPacker" },
                   { module => "Carp" },
                   { module => "Carp::Heavy" },
                   { module => "HTTP::Tiny" },
                   { module => "local::lib" },
                   { module => "Fcntl" },
                   { module => "File::Flock::Tiny" },
                   { module => "Devel::Declare" },
                   { module => "Function::Parameters" },
                   { module => "List::MoreUtils" },
                   { module => "List::Util" },
                   { module => "MooseX::Declare" },
                   { module => "NEXT" },
                   { module => "PerlX::Maybe" },
                   { module => "PerlX::QuoteOperator" },
                   { module => "Safe::Isa" },
                   { module => "Syntax::Collector" },
                   { module => "Syntax::Keyword::Junction" },
                   { module => "Try::Tiny" },
                   { module => "TryCatch" },
                   { module => "Web::Simple" },
                   { module => "aliased" },
                   { module => "autovivification" },
                   { module => "mro" },
                   { module => "true" },
                   { module => "Catalyst" },
                   { module => "Pinto" },
                   { module => "Pinto::Manual" },
                   { module => "AnyEvent" },
                   { module => "AnyEvent::HTTP" },
                   { module => "Coro" },
                   { module => "File::Basename" },
                   { module => "IO::Async" },
                   { module => "IO::Lambda" },
                   { module => "POE" },
                   { module => "Reflex" },
                   { module => "Regexp::Common" },
                   { module => "CHI" },
                   { module => "CHI::Driver::BerkeleyDB" },
                   { module => "CHI::Driver::File" },
                   { module => "CHI::Driver::Memcached" },
                   { module => "CHI::Driver::Memory" },
                   { module => "CHI::Driver::Redis" },
                   { module => "App::ForkProve" },
                   { module => "App::Prove" },
                   { module => "OX" },
                   { module => "Test::Aggregate" },
                   { module => "Test::Pretty" },
                   { module => "DBIx::Class" },
                   {
                     module => "DBIx::Class::Helper::ResultSet::CorrelateRelationship",
                   },
                   { module => "DBIx::Class::Helper::ResultSet::Me" },
                   { module => "DBIx::Class::Helper::Row::ProxyResultSetMethod" },
                   { module => "DBIx::Class::Helpers" },
                   { module => "DBIx::Class::ResultSet" },
                   { module => "App::Wallflower" },
                   { module => "File::Find" },
                   { module => "Wallflower" },
                   { module => "JSON" },
                   { module => "JSON::Types" },
                 ],
  summary     => "Modules mentioned in Perl Advent Calendar 2012",
};

1;
# ABSTRACT: Modules mentioned in Perl Advent Calendar 2012

__END__

=pod

=encoding UTF-8

=head1 NAME

Acme::CPANModules::Import::PerlAdvent::2012 - Modules mentioned in Perl Advent Calendar 2012

=head1 VERSION

This document describes version 0.001 of Acme::CPANModules::Import::PerlAdvent::2012 (from Perl distribution Acme-CPANModulesBundle-Import-PerlAdvent-2012), released on 2018-09-22.

=head1 DESCRIPTION

Modules mentioned in Perl Advent Calendar 2012.

This list is generated by extracting module names mentioned in [http://perladvent.org/2012/] (retrieved on 2016-11-06). Visit the URL for the full contents.

=head1 INCLUDED MODULES

=over

=item * L<File::Path>

=item * L<File::Spec>

=item * L<Moose>

=item * L<MooseX::Types::Path::Class>

=item * L<Path::Class>

=item * L<Scope::Upper>

=item * L<Dist::Zilla>

=item * L<Dist::Zilla::Plugin::ReportVersions::Tiny>

=item * L<Dist::Zilla::Plugin::Test::ReportPrereqs>

=item * L<Dancer>

=item * L<DBI>

=item * L<DDP>

=item * L<Data::Printer>

=item * L<DateTime>

=item * L<Digest>

=item * L<Digest::MD5>

=item * L<Safe>

=item * L<File::AtomicWrite>

=item * L<Dist::Zilla::Plugin::ShareDir::Tarball>

=item * L<ExtUtils::MakeMaker>

=item * L<File::ShareDir>

=item * L<File::ShareDir::Tarball>

=item * L<Module::Build>

=item * L<Module::Build::CleanInstall>

=item * L<Module::Build::Cookbook>

=item * L<Module::Pluggable>

=item * L<IO::Prompt::Hooked>

=item * L<IO::Prompt::Tiny>

=item * L<IO::Prompter>

=item * L<LWP>

=item * L<LWP::UserAgent>

=item * L<PSGI>

=item * L<Test::LWP::UserAgent>

=item * L<Test::Mock::LWP::Dispatch>

=item * L<Term::ExtendedColor>

=item * L<Web::Machine>

=item * L<pp>

=item * L<App::FatPacker>

=item * L<Carp>

=item * L<Carp::Heavy>

=item * L<HTTP::Tiny>

=item * L<local::lib>

=item * L<Fcntl>

=item * L<File::Flock::Tiny>

=item * L<Devel::Declare>

=item * L<Function::Parameters>

=item * L<List::MoreUtils>

=item * L<List::Util>

=item * L<MooseX::Declare>

=item * L<NEXT>

=item * L<PerlX::Maybe>

=item * L<PerlX::QuoteOperator>

=item * L<Safe::Isa>

=item * L<Syntax::Collector>

=item * L<Syntax::Keyword::Junction>

=item * L<Try::Tiny>

=item * L<TryCatch>

=item * L<Web::Simple>

=item * L<aliased>

=item * L<autovivification>

=item * L<mro>

=item * L<true>

=item * L<Catalyst>

=item * L<Pinto>

=item * L<Pinto::Manual>

=item * L<AnyEvent>

=item * L<AnyEvent::HTTP>

=item * L<Coro>

=item * L<File::Basename>

=item * L<IO::Async>

=item * L<IO::Lambda>

=item * L<POE>

=item * L<Reflex>

=item * L<Regexp::Common>

=item * L<CHI>

=item * L<CHI::Driver::BerkeleyDB>

=item * L<CHI::Driver::File>

=item * L<CHI::Driver::Memcached>

=item * L<CHI::Driver::Memory>

=item * L<CHI::Driver::Redis>

=item * L<App::ForkProve>

=item * L<App::Prove>

=item * L<OX>

=item * L<Test::Aggregate>

=item * L<Test::Pretty>

=item * L<DBIx::Class>

=item * L<DBIx::Class::Helper::ResultSet::CorrelateRelationship>

=item * L<DBIx::Class::Helper::ResultSet::Me>

=item * L<DBIx::Class::Helper::Row::ProxyResultSetMethod>

=item * L<DBIx::Class::Helpers>

=item * L<DBIx::Class::ResultSet>

=item * L<App::Wallflower>

=item * L<File::Find>

=item * L<Wallflower>

=item * L<JSON>

=item * L<JSON::Types>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANModulesBundle-Import-PerlAdvent-2012>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModulesBundle-Import-PerlAdvent-2012>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModulesBundle-Import-PerlAdvent-2012>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Acme::CPANModules> - about the Acme::CPANModules namespace

L<cpanmodules> - CLI tool to let you browse/view the lists

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
